@@ -19,7 +19,6 @@ const emptyFixture = resolve(__dirname, 'fixtures/empty')
 const depTypesFixture = resolve(__dirname, 'fixtures/dev-deps')
 const badJsonFixture = resolve(__dirname, 'fixtures/testing-peer-deps-bad-sw')
 const hiddenLockfileFixture = resolve(__dirname, 'fixtures/hidden-lockfile')
-const hiddenIdeallyInertLockfileFixture = resolve(__dirname, 'fixtures/hidden-lockfile-inert')
 const hidden = 'node_modules/.package-lock.json'
 const saxFixture = resolve(__dirname, 'fixtures/sax')
 
@@ -578,7 +577,7 @@ t.test('saving dependency-free shrinkwrap object', t => {
       resolve(`${dir}/node_modules/.package-lock.json`),
       'correct filepath on shrinkwrap instance'
     )
-    // save does not throw, but doens't write the file
+    // save does not throw, but doesn't write the file
     await sw.save()
     t.throws(() => fs.statSync(sw.filename))
   })
@@ -720,7 +719,7 @@ t.test('ignore yarn lock file parse errors', async t => {
   t.equal(s.yarnLock.entries.size, 0, 'did not get any entries out of it')
 })
 
-t.test('load a resolution from yarn.lock if we dont have our own', async t => {
+t.test('load a resolution from yarn.lock if we do not have our own', async t => {
   const path = t.testdir({
     'yarn.lock': `
 # THIS IS AN AUTOGENERATED FILE. DO NOT EDIT THIS FILE DIRECTLY.
@@ -865,15 +864,6 @@ t.test('load a hidden lockfile', async t => {
   t.equal(data.dependencies, undefined, 'deleted legacy metadata')
 })
 
-t.test('load a hidden lockfile with ideallyInert', async t => {
-  fs.utimesSync(resolve(hiddenIdeallyInertLockfileFixture, hidden), new Date(), new Date())
-  const s = await Shrinkwrap.load({
-    path: hiddenIdeallyInertLockfileFixture,
-    hiddenLockfile: true,
-  })
-  t.matchSnapshot(s.data)
-})
-
 t.test('load a fresh hidden lockfile', async t => {
   const sw = await Shrinkwrap.reset({
     path: hiddenLockfileFixture,
